﻿Imports System.Collections.ObjectModel

Imports MindFusion.Charting
Imports MindFusion.Charting.Components
Imports MindFusion.Drawing

Imports Color = System.Drawing.Color

Public Class MainForm

	Private Sub Form1_Load(ByVal sender As Object, ByVal e As System.EventArgs) Handles Me.Load
		' BarChart
		barChart.Series = GetSeriesCollection()
		barChart.Dock = DockStyle.Fill
		barChart.Title = "Bar Chart"
		barChart.BackColor = Color.WhiteSmoke

		barChart.AllowZoom = True
		barChart.AllowPan = True
		barChart.AllowMoveLegend = True

		barChart.XAxis.Title = ""
		barChart.XAxis.MinValue = 0
		barChart.XAxis.MaxValue = 3
		barChart.YAxis.Title = ""
		barChart.YAxis.MinValue = 0
		barChart.YAxis.MaxValue = 100

		barChart.ShowLegend = True
		barChart.LegendHorizontalAlignment = LayoutAlignment.Near
		barChart.LegendVerticalAlignment = LayoutAlignment.Near

		barChart.Theme = New Theme()
		barChart.Theme.CommonSeriesFills = GetBarFills()
		barChart.Theme.CommonSeriesStrokes = GetBarFills()
		barChart.Theme.LegendBackground = New SolidBrush(Color.FromArgb(200, 200, 200))
		barChart.Theme.LegendBorderStroke = New SolidBrush(Color.FromArgb(180, 180, 180))
		barChart.Theme.HighlightStroke = New SolidBrush(Color.DarkRed)
		barChart.Theme.HighlightStrokeThickness = 3
		barChart.Theme.DataLabelsBrush = New SolidBrush(Color.White)
		barChart.GridType = GridType.Horizontal
		barChart.Theme.GridLineStyle = System.Drawing.Drawing2D.DashStyle.Dash
		barChart.Theme.GridColor1 = Color.FromArgb(245, 245, 245)
		barChart.Theme.GridColor2 = Color.FromArgb(245, 245, 245)

		' PieChart
		pieChart.Series = New PieSeries(New Double() {20, 60, 40, 55}, New String() {"January", "February", "March", "April"},
		New String() {"January", "February", "March", "April"}) With {.Title = "Pie Series"}
		pieChart.Dock = DockStyle.Fill
		pieChart.Title = "Pie Chart"

		pieChart.AllowZoom = True
		pieChart.AllowRotate = True

		pieChart.ShowLegend = False
		pieChart.ShowDataLabels = LabelKinds.OuterLabel

		pieChart.Theme = New Theme()
		pieChart.Theme.SeriesFills = GetPieFills()
		pieChart.Theme.UniformSeriesStroke = New SolidBrush(Color.FromArgb(240, 240, 240))
		pieChart.Theme.SeriesStrokeThicknesses = New List(Of List(Of Double))() From { _
		 New List(Of Double)() From { _
		  15 _
		 } _
		}
		pieChart.Theme.HighlightStroke = New SolidBrush(Color.White)
		pieChart.Theme.HighlightStrokeThickness = 10
		pieChart.Theme.DataLabelsFontSize = 14

	End Sub

	Private Function GetSeriesCollection() As ObservableCollection(Of Series)
		Dim collection As New ObservableCollection(Of Series)()
		For i As Integer = 0 To 2
			If i = 0 Then
				collection.Add(New Series2D(New Double() {0, 1, 2, 3}, New Double() {20, 60, 40, 55},
		  New String() {"January", "February", "March", "April"}) With {.Title = "Series 1"})
			End If
			If i = 1 Then
				collection.Add(New Series2D(New Double() {0, 1, 2, 3}, New Double() {30, 70, 65, 19},
		  New String() {"May", "June", "July", "August"}) With {.Title = "Series 2"})
			End If
			If i = 2 Then
				collection.Add(New Series2D(New Double() {0, 1, 2, 3}, New Double() {22, 44, 33, 66},
		  New String() {"September", "October", "November", "December"}) With {.Title = "Series 3"})
			End If
		Next
		Return collection
	End Function

	Private Function GetBarFills() As List(Of Brush)
		Dim fills = New List(Of Brush)()

		fills.Add(New SolidBrush(Color.FromArgb(102, 154, 204)))
		fills.Add(New SolidBrush(Color.FromArgb(0, 52, 102)))
		fills.Add(New SolidBrush(Color.FromArgb(206, 0, 0)))

		Return fills
	End Function

	Private Function GetPieFills() As List(Of List(Of Brush))
		Dim fills = New List(Of List(Of Brush))()

		fills.Add(New List(Of Brush)() From {
			New SolidBrush(Color.FromArgb(102, 154, 204)),
			New SolidBrush(Color.FromArgb(192, 192, 192)),
			New SolidBrush(Color.FromArgb(0, 52, 102)),
			New SolidBrush(Color.FromArgb(206, 0, 0))
		})

		Return fills
	End Function

	Private Sub button1_Click(sender As Object, e As EventArgs) Handles button1.Click
		barChart.ResetZoom()
	End Sub

End Class
